@@ -1,222 +1,12 @@
 
 package WWW::Search::Scraper::FlipDog;
 
-=pod
-
-=head1 NAME
-
-WWW::Search::Scraper::FlipDog - class for searching www.FlipDog.com
-
-
-=head1 SYNOPSIS
-
-    use WWW::Search::Scraper;
-    use WWW::Search::Scraper::Response::Job;
-
-    $search = new WWW::Search::Scraper('FlipDog');
-
-    $search->setup_query($query, {options});
-
-    while ( my $response = $scraper->next_response() ) {
-        # $response is a WWW::Search::Scraper::Response::Job.
-    }
-
-=head1 DESCRIPTION
-
-FlipDog extends WWW::Search::Scraper.
-
-It handles making and interpreting FlipDog searches of F<http://www.FlipDog.com>.
-
-
-=head1 OPTIONS
-
-=over 8
-
-=item loc
-
-Many, many strings are allowed. Locations are categorized by state.
-See FlipDog.com for these option values ("3648 locations!" as of June 2001)
-
-=item cat
-
-      --- All Categories ---
-      Clerical/Administrative
-      Computing/MIS
-      Customer Service/Support
-      Education/Training
-      Engineering
-      Financial Services
-      Government/Non Profit
-      Health Care
-      Human Resources
-      Manufacturing/Business Operations
-      Marketing/Advertising
-      Media
-      Other
-      Professional Services
-      Sales
-      Travel/Hospitality
-
-To this you need to add a "-" and the "job function". 
-The options for job function are dependant on the Job Category, so
-for some of the categories the functions are:
-
-=back
-
-=over 16
-
-=item Clerical/Administrative
-
-    --- All Job Functions in Category ---
-    Other
-
-=item Computing/MIS
-
-    --- All Job Functions in Category ---
-    Database Administration
-    Internet Development
-    Network/System Administration
-    Other
-    Quality Assurance/Testing
-    Software Development
-    Systems Analysis
-    Technical Support/Help Desk
-
-=item Customer Service/Support
-
-    --- All Job Functions in Category ---
-    Other
-
-=item Education/Training
-
-  --- All Job Functions in Category ---
-  Colleges/Universities
-  K to 12 Education
-  Other
-  Technical/Trade Schools
-  Training   
-
-=item Engineering
-
-  --- All Job Functions in Category ---
-  Chemical
-  Civil
-  Design/Industrial
-  Electrical/Hardware
-  Mechanical
-  Operations
-  Other   
-
-=item Financial Services
-
-  --- All Job Functions in Category ---
-  Accounting
-  Banking
-  Finance
-  Insurance
-  Other
-  Securities/Asset Management   
-
-=item Government/Non Profit
-
-    --- All Job Functions in Category ---
-    Other
-
-=item Health Care
- 
-  --- All Job Functions in Category ---
-  Administration
-  Medical
-  Nursing
-  Other
-  Pharmaceutical   
-
-=item Human Resources
-
-    --- All Job Functions in Category ---
-    Other
-
-=item Manufacturing/Business Operations
- 
-  --- All Job Functions in Category ---
-  Construction/Trades
-  Facilities Management
-  Logistics/Distribution
-  Manufacturing
-  Other
-  Program/Project Management
-  Purchasing   
-
-=item Marketing/Advertising
- 
-  --- All Job Functions in Category ---
-  Advertising
-  Market Research
-  Marketing Communications
-  Other
-  Product Management
-  Public Relations   
-
-=item Media
- 
-  --- All Job Functions in Category ---
-  Broadcasting
-  Graphic Arts/Design
-  Journalism
-  Other
-  Publishing/Technical Writing   
-
-=item Other
-
-    --- All Job Functions in Category ---
-    Other
-
-=item Professional Services
- 
-  --- All Job Functions in Category ---
-  Legal Services
-  Management Consulting
-  Other   
-
-=item Sales
- 
-  --- All Job Functions in Category ---
-  Account Management
-  Business Development
-  Direct Sales
-  Merchandising/Retail
-  Other   
-
-=item Travel/Hospitality
- 
-  --- All Job Functions in Category ---
-  Other
-  Restaurant/Food Services
-  Travel/Recreation/Lodging   
-
-=back
-
-=head1 AUTHOR
-
-C<WWW::Search::FlipDog> is written and maintained
-by Glenn Wood, <glenwood@alumni.caltech.edu>.
-
-=head1 COPYRIGHT
-
-Copyright (c) 2001 Glenn Wood
-All rights reserved.
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
-=cut
-
 
 #####################################################################
 use strict;
 use vars qw(@ISA $VERSION);
 @ISA = qw(WWW::Search::Scraper);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 use WWW::Search::Scraper(qw(1.41 trimLFs trimLFLFs));
 require WWW::SearchResult;
@@ -276,7 +66,7 @@ sub native_setup_search
                        ,[ 'TR', '#1' ]
                     ]
                 ]
-               ,[ 'BOGUS', -2 ] # The last two hits are bogus.
+#               ,[ 'BOGUS', -2 ] # The last two hits are bogus.
             ]
         ]
     ]
@@ -375,3 +165,202 @@ sub jobType { return $_[0]->_elem('jobType'); }
 
 
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+WWW::Search::Scraper::FlipDog - class for searching www.FlipDog.com
+
+
+=head1 SYNOPSIS
+
+    use WWW::Search::Scraper;
+    use WWW::Search::Scraper::Response::Job;
+
+    $search = new WWW::Search::Scraper('FlipDog');
+
+    $search->setup_query($query, {options});
+
+    while ( my $response = $scraper->next_response() ) {
+        # $response is a WWW::Search::Scraper::Response::Job.
+    }
+
+=head1 DESCRIPTION
+
+FlipDog extends WWW::Search::Scraper.
+
+It handles making and interpreting FlipDog searches of F<http://www.FlipDog.com>.
+
+
+=head1 OPTIONS
+
+=over 8
+
+=item loc
+
+Many, many strings are allowed. Locations are categorized by state.
+See FlipDog.com for these option values ("3648 locations!" as of June 2001)
+
+=item cat
+
+      --- All Categories ---
+      Clerical/Administrative
+      Computing/MIS
+      Customer Service/Support
+      Education/Training
+      Engineering
+      Financial Services
+      Government/Non Profit
+      Health Care
+      Human Resources
+      Manufacturing/Business Operations
+      Marketing/Advertising
+      Media
+      Other
+      Professional Services
+      Sales
+      Travel/Hospitality
+
+To this you need to add a "-" and the "job function", or
+you may specify "All Job Functions in Category" by leaving off the "-" and "job function".
+ 
+The options for job function are dependant on the Job Category, so
+for some of the categories the functions are:
+
+=back
+
+=over 16
+
+=item Clerical/Administrative
+
+    Other
+
+=item Computing/MIS
+
+    Database Administration
+    Internet Development
+    Network/System Administration
+    Other
+    Quality Assurance/Testing
+    Software Development
+    Systems Analysis
+    Technical Support/Help Desk
+
+=item Customer Service/Support
+
+    Other
+
+=item Education/Training
+
+  Colleges/Universities
+  K to 12 Education
+  Other
+  Technical/Trade Schools
+  Training   
+
+=item Engineering
+
+  Chemical
+  Civil
+  Design/Industrial
+  Electrical/Hardware
+  Mechanical
+  Operations
+  Other   
+
+=item Financial Services
+
+  Accounting
+  Banking
+  Finance
+  Insurance
+  Other
+  Securities/Asset Management   
+
+=item Government/Non Profit
+
+    Other
+
+=item Health Care
+ 
+  Administration
+  Medical
+  Nursing
+  Other
+  Pharmaceutical   
+
+=item Human Resources
+
+    Other
+
+=item Manufacturing/Business Operations
+ 
+  Construction/Trades
+  Facilities Management
+  Logistics/Distribution
+  Manufacturing
+  Other
+  Program/Project Management
+  Purchasing   
+
+=item Marketing/Advertising
+ 
+  Advertising
+  Market Research
+  Marketing Communications
+  Other
+  Product Management
+  Public Relations   
+
+=item Media
+ 
+  Broadcasting
+  Graphic Arts/Design
+  Journalism
+  Other
+  Publishing/Technical Writing   
+
+=item Other
+
+    Other
+
+=item Professional Services
+ 
+  Legal Services
+  Management Consulting
+  Other   
+
+=item Sales
+ 
+  Account Management
+  Business Development
+  Direct Sales
+  Merchandising/Retail
+  Other   
+
+=item Travel/Hospitality
+ 
+  Other
+  Restaurant/Food Services
+  Travel/Recreation/Lodging   
+
+=back
+
+=head1 AUTHOR
+
+C<WWW::Search::FlipDog> is written and maintained
+by Glenn Wood, <glenwood@alumni.caltech.edu>.
+
+=head1 COPYRIGHT
+
+Copyright (c) 2001 Glenn Wood
+All rights reserved.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
+
+
